// StarPlot - A program for interactively viewing 3D maps of stellar positions.
// Copyright (C) 2000  Kevin B. McCarty
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


#ifndef _CONVERT_H
#define _CONVERT_H

#include "parse.h"
#include "../classes/star.h"

#if HAVE_STD__OSTRINGSTREAM
#include <sstream>
#endif

#ifndef DOCDIR
#define DOCDIR "/usr/local/share/doc/starplot"
#endif

#ifndef PROGNAME
#define PROGNAME "starconvert"
#endif

#endif // #ifndef _CONVERT_H
